==> rwma-0.1.tar.gz: rwma-0.1/modules/EUdict.rb <==

# EUdict online translator
# plugin that uses www.eudict.com for translating between number of
# languages
#
# available options:
#       default_translate   - default language combination for translation
#                             (for available options look down)
#       logging             - write to log (default is false)
#
# available commands:
#       none
#
# At the prompt, language  combinations will be shown. User can type just
# a desired word (or phrase) to get it translated with default combination, 
# or select language combination from the list and then, after space, type 
# the desired word or phrase
#
# This plugin requires Mechanize gem to work. You can install it with 
# "gem install mechanize" (as root)

#
# Copyright 2010 Igor Brkic <igor@hyperglitch.com>
#

require 'net/http'

require 'rubygems'
require 'mechanize'

class EUdict

    def initialize io
        @io=io

        # available language combination
        # (dmenu cannot correctly display kanji characters, so japanese 
        # kanji translations are disabled)
        @combinations={    
            "catfre"=>"catalan->french",
            "chieng"=>"chinese->english",
            "crocze"=>"croatian->czech",

            "crodut"=>"croatian->dutch",
            "croeng"=>"croatian->english",
            "crofre"=>"croatian->french",
            "croger"=>"croatian->german",
            "crohun"=>"croatian->hungarian",
            "croita"=>"croatian->italian",

            "crolat"=>"croatian->latin",
            "croslo"=>"croatian->slovenian",
            "crospa"=>"croatian->spanish",
            "czecro"=>"czech->croatian",
            "dutcro"=>"dutch->croatian",
            "duteng"=>"dutch->english",

            "engchi"=>"english->chinese",
            "engcro"=>"english->croatian",
            "engdut"=>"english->dutch",
            "engfin"=>"english->finnish",
            "engfre"=>"english->french",
            "engger"=>"english->german",

            "engind"=>"english->indonesian",
            "engita"=>"english->italian",
            "engjap"=>"english->japanese",
            #"engjpk"=>"english->japanese(kanji)",
            "englat"=>"english->latin",
            "engnor"=>"english->norwegian",

            "engpol"=>"english->polish",
            "engrus"=>"english->russian",
            "engspa"=>"english->spanish",
            "engswe"=>"english->swedish",
            "fineng"=>"finnish->english",
            "frecat"=>"french->catalan",

            "frecro"=>"french->croatian",
            "freeng"=>"french->english",
            "freger"=>"french->german",
            "freita"=>"french->italian",
            "frejap"=>"french->japanese",
            #"frejpk"=>"french->japanese(kanji)",

            "frepor"=>"french->portuguese",
            "gercro"=>"german->croatian",
            "gereng"=>"german->english",
            "gerfre"=>"german->french",
            "gerita"=>"german->italian",
            "gerlat"=>"german->latin",

            "gerspa"=>"german->spanish",
            "huncro"=>"hungarian->croatian",
            "indeng"=>"indonesian->english",
            "itacro"=>"italian->croatian",
            "itaeng"=>"italian->english",
            "itafre"=>"italian->french",

            "itager"=>"italian->german"	,
            "japeng"=>"japanese->english",
            "japfre"=>"japanese->french",
            #"jpkeng"=>"japanese(kanji)->english",
            #"jpkfre"=>"japanese(kanji)->french",
            "latcro"=>"latin->croatian",

            "lateng"=>"latin->english",
            "latger"=>"latin->german",
            "noreng"=>"norwegian->english",
            "poleng"=>"polish->english",
            "porfre"=>"portuguese->french",
            "ruseng"=>"russian->english",

            "slocro"=>"slovenian->croatian",
            "spacro"=>"spanish->croatian",
            "spaeng"=>"spanish->english",
            "spager"=>"spanish->german",
            "sweeng"=>"swedish->english"
        }
    end

    def setup options
        @default=options[:default_translate]||nil
        @logging=options[:logging]||false
    end

    def run action=[]
        resp=@io.input @combinations.values, "[EUdict translator]"

        if resp!='' then
            resp=resp.split

            if @combinations.has_value? resp[0] then
                lang=@combinations.select{|k,v| v==resp[0]}[0][0]
                word=resp[1..-1].join(' ')
            else
                lang=@default
                word=resp.join(' ')
            end

            list=[]
            begin
                p=Mechanize.new.get("http://m.eudict.com/index.php?lang=#{lang}&word=#{URI.escape(word)}")
                p.parser.xpath('//div[@class="content"]/dl/dd/a/text()').each{|w|
                    list<<w.to_s
                }
            rescue SocketError=>err
                list<<"cannot connect to eudict.com"
            end

            if list.empty? then list<<"no results" end
            @io.input list, "[results for \"#{word}\"]"

            @io.log("[EUdict] translated word #{word} with combination #{lang}") if @logging
        end

    end
end

==> rwma-0.13.tar.gz: rwma-0.13/modules/EUdict.rb <==

# EUdict online translator
# plugin that uses www.eudict.com for translating between number of
# languages
#
# available options:
#       default_translate   - default language combination for translation
#                             (for available options look down)
#       logging             - write to log (default is false)
#
# available commands:
#       none
#
# At the prompt, language  combinations will be shown. User can type just
# a desired word (or phrase) to get it translated with default combination, 
# or select language combination from the list and then, after space, type 
# the desired word or phrase
#
# This plugin requires Mechanize gem to work. You can install it with 
# "gem install mechanize" (as root)

#
# Copyright 2010 Igor Brkic <igor@hyperglitch.com>
#

require 'net/http'

require 'rubygems'
require 'mechanize'

class EUdict

    def initialize io
        @io=io

        # available language combination
        # (dmenu cannot correctly display kanji characters, so japanese 
        # kanji translations are disabled)
        @combinations={    
            "catfre"=>"catalan->french",
            "chieng"=>"chinese->english",
            "crocze"=>"croatian->czech",

            "crodut"=>"croatian->dutch",
            "croeng"=>"croatian->english",
            "crofre"=>"croatian->french",
            "croger"=>"croatian->german",
            "crohun"=>"croatian->hungarian",
            "croita"=>"croatian->italian",

            "crolat"=>"croatian->latin",
            "croslo"=>"croatian->slovenian",
            "crospa"=>"croatian->spanish",
            "czecro"=>"czech->croatian",
            "dutcro"=>"dutch->croatian",
            "duteng"=>"dutch->english",

            "engchi"=>"english->chinese",
            "engcro"=>"english->croatian",
            "engdut"=>"english->dutch",
            "engfin"=>"english->finnish",
            "engfre"=>"english->french",
            "engger"=>"english->german",

            "engind"=>"english->indonesian",
            "engita"=>"english->italian",
            "engjap"=>"english->japanese",
            #"engjpk"=>"english->japanese(kanji)",
            "englat"=>"english->latin",
            "engnor"=>"english->norwegian",

            "engpol"=>"english->polish",
            "engrus"=>"english->russian",
            "engspa"=>"english->spanish",
            "engswe"=>"english->swedish",
            "fineng"=>"finnish->english",
            "frecat"=>"french->catalan",

            "frecro"=>"french->croatian",
            "freeng"=>"french->english",
            "freger"=>"french->german",
            "freita"=>"french->italian",
            "frejap"=>"french->japanese",
            #"frejpk"=>"french->japanese(kanji)",

            "frepor"=>"french->portuguese",
            "gercro"=>"german->croatian",
            "gereng"=>"german->english",
            "gerfre"=>"german->french",
            "gerita"=>"german->italian",
            "gerlat"=>"german->latin",

            "gerspa"=>"german->spanish",
            "huncro"=>"hungarian->croatian",
            "indeng"=>"indonesian->english",
            "itacro"=>"italian->croatian",
            "itaeng"=>"italian->english",
            "itafre"=>"italian->french",

            "itager"=>"italian->german"	,
            "japeng"=>"japanese->english",
            "japfre"=>"japanese->french",
            #"jpkeng"=>"japanese(kanji)->english",
            #"jpkfre"=>"japanese(kanji)->french",
            "latcro"=>"latin->croatian",

            "lateng"=>"latin->english",
            "latger"=>"latin->german",
            "noreng"=>"norwegian->english",
            "poleng"=>"polish->english",
            "porfre"=>"portuguese->french",
            "ruseng"=>"russian->english",

            "slocro"=>"slovenian->croatian",
            "spacro"=>"spanish->croatian",
            "spaeng"=>"spanish->english",
            "spager"=>"spanish->german",
            "sweeng"=>"swedish->english"
        }
    end

    def setup options
        @default=options[:default_translate]||nil
        @logging=options[:logging]||false
    end

    def run action=[]
        resp=@io.input @combinations.values, "[EUdict translator]"

        if resp!='' then
            resp=resp.split

            if @combinations.has_value? resp[0] then
                lang=@combinations.select{|k,v| v==resp[0]}

                lang=lang.to_a if lang.class==Hash # in Ruby1.9 select returns Hash

                lang=lang[0][0]
                
                word=resp[1..-1].join(' ')
                return if word.empty?
            else
                lang=@default
                word=resp.join(' ')
            end

            list=[]
            begin
                p=Mechanize.new.get("http://m.eudict.com/index.php?lang=#{lang}&word=#{URI.escape(word)}")
                p.parser.xpath('//div[@class="content"]/dl/dd/a/text()').each{|w|
                    list<<w.to_s
                }
            rescue SocketError=>err
                list<<"cannot connect to eudict.com"
            end

            if list.empty? then list<<"no results" end
            @io.input list, "[results for \"#{word}\"]"

            @io.log("[EUdict] translated word #{word} with combination #{lang}") if @logging
        end

    end
end
